@@ -1,6 +1,6 @@
 package Mojo::Webqq;
 use strict;
-$Mojo::Webqq::VERSION = "1.7.0";
+$Mojo::Webqq::VERSION = "1.7.1";
 use base qw(Mojo::Base);
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -75,8 +75,10 @@ has is_ready                => 0;
 has ua_retry_times          => 5;
 has is_first_login          => -1;
 has login_state             => "init";#init|relogin|success|scaning|confirming
+has qrcode_count            => 0;
+has qrcode_count_max        => 10;
 has send_failure_count      => 0;
-has send_failure_count_max  => 3;
+has send_failure_count_max  => 5;
 has poll_failure_count      => 0;
 has poll_failure_count_max  => 3;
 has message_queue           => sub { $_[0]->gen_message_queue };
@@ -138,12 +140,20 @@ sub on {
 
 sub new {
     my $class = shift;
-    my $self  = $class->SUPER::new(@_);
+    my $self  = $class->Mojo::Base::new(@_);
     #$ENV{MOJO_USERAGENT_DEBUG} = $self->{ua_debug};
     if(not defined $self->{qq}){
         $self->fatal("客户端初始化缺少qq参数");
         $self->exit();
     }
+    $self->on(qrcode_expire=>sub{
+        my($self) = @_;
+        my $count = $self->qrcode_count;
+        $self->qrcode_count(++$count);
+        if($self->qrcode_count >= $self->qrcode_count_max){
+            $self->stop();
+        }
+    });
     $self->on(model_update=>sub{
         my($self,$type,$status)=@_;
         $self->model_status->{$type} = $status;
