@@ -68,14 +68,12 @@ sub is_support_model_ext {
 }
 sub get_model_status{
     my $self = shift;
-    if(     defined $self->model_status->{user} 
-        and defined $self->model_status->{friend} 
+    if(     defined $self->model_status->{friend} 
         and defined $self->model_status->{group}
     ){
         my $is_fail =
-               $self->model_status->{user} == 0
-            && $self->model_status->{friend} == 0
-            && $self->model_status->{group} == 0
+                $self->model_status->{friend} == 0
+            &&  $self->model_status->{group} == 0
         ;
         return $is_fail?0:1;
     }
@@ -189,7 +187,7 @@ sub add_friend {
     }
     my $f = $self->search_friend(id => $friend->id);
     if(defined $f){
-        $f = $friend;
+        %$f = %$friend;
     }
     else{
         push @{$self->friend},$friend;
@@ -283,7 +281,7 @@ sub add_group{
     }
     my $g = $self->search_group(gid => $group->gid);
     if(defined $g){
-        $g = $group;
+        %$g = %$group;
     }
     else{#new group
         push @{$self->group},$group;
@@ -465,7 +463,7 @@ sub add_discuss {
     }
     my $d = $self->search_discuss(did => $discuss->did);
     if(defined $d){
-        $d = $discuss;
+        %$d = %$discuss;
     }
     else{#new discuss
         push @{$self->discuss},$discuss;
